These functions select a bandwidth sigma
for the kernel estimator of point process intensity
computed by density.ppp
or other appropriate functions.
They can be applied to a point pattern
belonging to any class "ppp", "lpp", "pp3"
or "ppx".
The bandwidth \(\sigma\) is computed by the rule of thumb
of Scott (1992, page 152, equation 6.42).
The bandwidth is proportional to \(n^{-1/(d+4)}\)
where \(n\) is the number of points and \(d\) is the number of
spatial dimensions.
This rule is very fast to compute. It typically produces a larger bandwidth
than bw.diggle. It is useful for estimating
gradual trend.
If isotropic=FALSE (the default), bw.scott provides a
separate bandwidth for each coordinate axis, and the result of the
function is a vector, of length equal to the number of coordinates.
If isotropic=TRUE, a single bandwidth value is computed
and the result is a single numeric value.
bw.scott.iso(X) is equivalent to
bw.scott(X, isotropic=TRUE).
The default value of \(d\) is as follows:
|
class |
dimension |
"ppp" |
2 |
"lpp" |
1 |
"pp3" |
3 |
The use of d=1 for point patterns on a linear network
(class "lpp") was proposed by McSwiggan et al (2016)
and Rakshit et al (2019).